==> cost-interface-0.2.3-sources.jar: com/chinayanghe/tpm/cost/vo/in/CostPageFormVo.java <==
package com.chinayanghe.tpm.cost.vo.in;

import java.io.Serializable;

/**
 * Created by wanggq on 2017/6/12.
 */
public class CostPageFormVo implements Serializable {

    private String managerForm; //管理信息
    private String activityForm; //活动信息
    private String financialForm; //财务信息
    private String finaceItemJson;//财务明细
    private String activityItemJson; //活动信息
    private Integer isIndividualPromote; //是否促销
    private String regionMktValue; //区域信息
    private Integer status; //状态 可为null
    private String deleteIds;//删除行记录
    private String userId; //用户登陆帐号
    private String formType; //表单类型 申请 登记 核报 临时报备
    private String costType; //费用类型 二级活动编码
    private String flag;  //是否最终审批通过0否 1是
    private String promotionItem; //促销信息json


    public String getManagerForm() {
        return managerForm;
    }

    public void setManagerForm(String managerForm) {
        this.managerForm = managerForm;
    }

    public String getActivityForm() {
        return activityForm;
    }

    public void setActivityForm(String activityForm) {
        this.activityForm = activityForm;
    }

    public String getFinancialForm() {
        return financialForm;
    }

    public void setFinancialForm(String financialForm) {
        this.financialForm = financialForm;
    }

    public String getActivityItemJson() {
        return activityItemJson;
    }

    public void setActivityItemJson(String activityItemJson) {
        this.activityItemJson = activityItemJson;
    }

    public Integer getIsIndividualPromote() {
        return isIndividualPromote;
    }

    public void setIsIndividualPromote(Integer isIndividualPromote) {
        this.isIndividualPromote = isIndividualPromote;
    }

    public String getRegionMktValue() {
        return regionMktValue;
    }

    public void setRegionMktValue(String regionMktValue) {
        this.regionMktValue = regionMktValue;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getDeleteIds() {
        return deleteIds;
    }

    public void setDeleteIds(String deleteIds) {
        this.deleteIds = deleteIds;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getFormType() {
        return formType;
    }

    public void setFormType(String formType) {
        this.formType = formType;
    }

    public String getCostType() {
        return costType;
    }

    public void setCostType(String costType) {
        this.costType = costType;
    }

    public String getFlag() {
        return flag;
    }

    public void setFlag(String flag) {
        this.flag = flag;
    }

    public String getPromotionItem() {
        return promotionItem;
    }

    public void setPromotionItem(String promotionItem) {
        this.promotionItem = promotionItem;
    }

    public String getFinaceItemJson() {
        return finaceItemJson;
    }

    public void setFinaceItemJson(String finaceItemJson) {
        this.finaceItemJson = finaceItemJson;
    }

    @Override
    public String toString() {
        return "CostPageFormVo{" +
                "managerForm='" + managerForm + '\'' +
                ", activityForm='" + activityForm + '\'' +
                ", financialForm='" + financialForm + '\'' +
                ", finaceItemJson='" + finaceItemJson + '\'' +
                ", activityItemJson='" + activityItemJson + '\'' +
                ", isIndividualPromote=" + isIndividualPromote +
                ", regionMktValue='" + regionMktValue + '\'' +
                ", status=" + status +
                ", deleteIds='" + deleteIds + '\'' +
                ", userId='" + userId + '\'' +
                ", formType='" + formType + '\'' +
                ", costType='" + costType + '\'' +
                ", flag='" + flag + '\'' +
                ", promotionItem='" + promotionItem + '\'' +
                '}';
    }
}

==> cost-interface-0.2.6-sources.jar: com/chinayanghe/tpm/cost/vo/in/CostPageFormVo.java <==
package com.chinayanghe.tpm.cost.vo.in;

import java.io.Serializable;

/**
 * Created by wanggq on 2017/6/12.
 */
public class CostPageFormVo implements Serializable {

    private String managerForm; //管理信息
    private String activityForm; //活动信息
    private String financialForm; //财务信息
    private String finaceItemJson;//财务明细
    private String activityItemJson; //活动信息
    private Integer isIndividualPromote; //是否促销
    private String regionMktValue; //区域信息
    private Integer status; //状态 可为null
    private String deleteIds;//删除行记录
    private String userId; //用户登陆帐号
    private String formType; //表单类型 申请 登记 核报 临时报备
    private String costType; //费用类型 二级活动编码
    private String flag;  //是否最终审批通过0否 1是
    private String promotionItem; //促销信息json
    private String isRestart; //是否驳回，再开启 'y'


    public String getManagerForm() {
        return managerForm;
    }

    public void setManagerForm(String managerForm) {
        this.managerForm = managerForm;
    }

    public String getActivityForm() {
        return activityForm;
    }

    public void setActivityForm(String activityForm) {
        this.activityForm = activityForm;
    }

    public String getFinancialForm() {
        return financialForm;
    }

    public void setFinancialForm(String financialForm) {
        this.financialForm = financialForm;
    }

    public String getActivityItemJson() {
        return activityItemJson;
    }

    public void setActivityItemJson(String activityItemJson) {
        this.activityItemJson = activityItemJson;
    }

    public Integer getIsIndividualPromote() {
        return isIndividualPromote;
    }

    public void setIsIndividualPromote(Integer isIndividualPromote) {
        this.isIndividualPromote = isIndividualPromote;
    }

    public String getRegionMktValue() {
        return regionMktValue;
    }

    public void setRegionMktValue(String regionMktValue) {
        this.regionMktValue = regionMktValue;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getDeleteIds() {
        return deleteIds;
    }

    public void setDeleteIds(String deleteIds) {
        this.deleteIds = deleteIds;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getFormType() {
        return formType;
    }

    public void setFormType(String formType) {
        this.formType = formType;
    }

    public String getCostType() {
        return costType;
    }

    public void setCostType(String costType) {
        this.costType = costType;
    }

    public String getFlag() {
        return flag;
    }

    public void setFlag(String flag) {
        this.flag = flag;
    }

    public String getPromotionItem() {
        return promotionItem;
    }

    public void setPromotionItem(String promotionItem) {
        this.promotionItem = promotionItem;
    }

    public String getFinaceItemJson() {
        return finaceItemJson;
    }

    public void setFinaceItemJson(String finaceItemJson) {
        this.finaceItemJson = finaceItemJson;
    }

    public String getIsRestart() {
        return isRestart;
    }

    public void setIsRestart(String isRestart) {
        this.isRestart = isRestart;
    }

    @Override
    public String toString() {
        return "CostPageFormVo{" +
                "managerForm='" + managerForm + '\'' +
                ", activityForm='" + activityForm + '\'' +
                ", financialForm='" + financialForm + '\'' +
                ", finaceItemJson='" + finaceItemJson + '\'' +
                ", activityItemJson='" + activityItemJson + '\'' +
                ", isIndividualPromote=" + isIndividualPromote +
                ", regionMktValue='" + regionMktValue + '\'' +
                ", status=" + status +
                ", deleteIds='" + deleteIds + '\'' +
                ", userId='" + userId + '\'' +
                ", formType='" + formType + '\'' +
                ", costType='" + costType + '\'' +
                ", flag='" + flag + '\'' +
                ", promotionItem='" + promotionItem + '\'' +
                ", isRestart='" + isRestart + '\'' +
                '}';
    }
}
